"use strict";

exports.__esModule = true;
exports.default = void 0;

var _ramda = require("ramda");

var _util = require("./util");

/**
 * A port of [Ramda's evolve()](http://ramdajs.com/docs/#evolve), but the
 * transforms are _always_ applied regardless if the key/value pair exists in
 * the input object or not.
 *
 *
 * @func
 * @sig {k: (a -> b)} -> {k: v} -> {k: v}
 * @param {Object} transforms An object whose values may be transform functions that
 * need to be wrapped in try/catch
 * @param {Object} input The input object to pass through prop-level transformations
 * @returns {Object} The modified input object, with any prop-level transforms
 * applied to it
 */
var alwaysEvolve = (0, _ramda.curry)(function (transforms, input) {
  var result = {};
  var spec = (0, _util.safeSpecTransforms)(transforms);
  var object = (0, _util.objectify)(input);
  (0, _ramda.keys)(spec).forEach(function (key) {
    result[key] = (0, _ramda.cond)([[(0, _ramda.is)(Function), (0, _ramda.applyTo)(object[key])], [_util.isPlainObj, alwaysEvolve(_ramda.__, object[key])], [_ramda.T, _ramda.identity]])(spec[key]);
  });
  return (0, _ramda.merge)(input, result);
});
var _default = alwaysEvolve;
exports.default = _default;